tokenizer\_tools.tagset package
===============================

Subpackages
-----------

.. toctree::

   tokenizer_tools.tagset.NER
   tokenizer_tools.tagset.converter
   tokenizer_tools.tagset.offset

Submodules
----------

tokenizer\_tools.tagset.BMES module
-----------------------------------

.. automodule:: tokenizer_tools.tagset.BMES
   :members:
   :undoc-members:
   :show-inheritance:

tokenizer\_tools.tagset.exceptions module
-----------------------------------------

.. automodule:: tokenizer_tools.tagset.exceptions
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: tokenizer_tools.tagset
   :members:
   :undoc-members:
   :show-inheritance:
